==> jc-1.4.0.tar.gz: soot/baf/internal/BInstanceCastInst.h <==
// public class soot.baf.internal.BInstanceCastInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 23b30f4d1fa73e43 soot_baf_internal_BInstanceCastInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_BInstanceCastInst_H_
#define _JC_soot_baf_internal_BInstanceCastInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BInstanceCastInst$sub_refs	_jc_soot_baf_internal_BInstanceCastInst$sub_refs;
typedef struct _jc_soot_baf_internal_BInstanceCastInst$sub_nonrefs	_jc_soot_baf_internal_BInstanceCastInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BInstanceCastInst$refs	_jc_soot_baf_internal_BInstanceCastInst$refs;
typedef struct _jc_soot_baf_internal_BInstanceCastInst$nonrefs	_jc_soot_baf_internal_BInstanceCastInst$nonrefs;
typedef struct _jc_soot_baf_internal_BInstanceCastInst$object	_jc_soot_baf_internal_BInstanceCastInst$object;

typedef const struct _jc_soot_baf_internal_BInstanceCastInst$vmethods	_jc_soot_baf_internal_BInstanceCastInst$vmethods;
typedef const struct _jc_soot_baf_internal_BInstanceCastInst$vtable	_jc_soot_baf_internal_BInstanceCastInst$vtable;
typedef const struct _jc_soot_baf_internal_BInstanceCastInst$vtype	_jc_soot_baf_internal_BInstanceCastInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BInstanceCastInst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_soot_Type$object *);

// Virtual methods
extern void _jc_soot_baf_internal_BInstanceCastInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BInstanceCastInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_BInstanceCastInst$method$getCastType$ae2cd82a88b9d4af(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
extern jint _jc_soot_baf_internal_BInstanceCastInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
extern jint _jc_soot_baf_internal_BInstanceCastInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BInstanceCastInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
extern jint _jc_soot_baf_internal_BInstanceCastInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
extern jint _jc_soot_baf_internal_BInstanceCastInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
extern void _jc_soot_baf_internal_BInstanceCastInst$method$setCastType$d5c81c672c992d0a(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getCastType$ae2cd82a88b9d4af;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getOutMachineCount$382bb5439d011100;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$setCastType$d5c81c672c992d0a;

// Virtual methods structure
struct _jc_soot_baf_internal_BInstanceCastInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
	struct _jc_soot_Type$object	*(*getCastType$ae2cd82a88b9d4af)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *);
	void	(*setCastType$d5c81c672c992d0a)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_baf_internal_BInstanceCastInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_BInstanceCastInst$vmethods	soot_baf_internal_BInstanceCastInst;
};

// Vtype
struct _jc_soot_baf_internal_BInstanceCastInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BInstanceCastInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BInstanceCastInst$sub_refs {
	struct _jc_soot_Type$object	*castType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BInstanceCastInst$refs {
    _jc_soot_baf_internal_BInstanceCastInst$sub_refs	soot_baf_internal_BInstanceCastInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BInstanceCastInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BInstanceCastInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_BInstanceCastInst$sub_nonrefs	soot_baf_internal_BInstanceCastInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BInstanceCastInst$object {
	_jc_soot_baf_internal_BInstanceCastInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BInstanceCastInst$vtype	*vtype;
	_jc_soot_baf_internal_BInstanceCastInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BInstanceCastInst$vtype _jc_soot_baf_internal_BInstanceCastInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BInstanceCastInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BInstanceCastInst$class_object;

#endif	/* _JC_soot_baf_internal_BInstanceCastInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BInstanceCastInst.h <==
// public class soot.baf.internal.BInstanceCastInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 23b30f4d1fa73e43 soot_baf_internal_BInstanceCastInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_BInstanceCastInst_H_
#define _JC_soot_baf_internal_BInstanceCastInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BInstanceCastInst$sub_refs	_jc_soot_baf_internal_BInstanceCastInst$sub_refs;
typedef struct _jc_soot_baf_internal_BInstanceCastInst$sub_nonrefs	_jc_soot_baf_internal_BInstanceCastInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BInstanceCastInst$refs	_jc_soot_baf_internal_BInstanceCastInst$refs;
typedef struct _jc_soot_baf_internal_BInstanceCastInst$nonrefs	_jc_soot_baf_internal_BInstanceCastInst$nonrefs;
typedef struct _jc_soot_baf_internal_BInstanceCastInst$object	_jc_soot_baf_internal_BInstanceCastInst$object;

typedef const struct _jc_soot_baf_internal_BInstanceCastInst$vmethods	_jc_soot_baf_internal_BInstanceCastInst$vmethods;
typedef const struct _jc_soot_baf_internal_BInstanceCastInst$vtable	_jc_soot_baf_internal_BInstanceCastInst$vtable;
typedef const struct _jc_soot_baf_internal_BInstanceCastInst$vtype	_jc_soot_baf_internal_BInstanceCastInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BInstanceCastInst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BInstanceCastInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BInstanceCastInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_BInstanceCastInst$method$getCastType$ae2cd82a88b9d4af(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BInstanceCastInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BInstanceCastInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BInstanceCastInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BInstanceCastInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BInstanceCastInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_BInstanceCastInst$method$setCastType$d5c81c672c992d0a(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getCastType$ae2cd82a88b9d4af;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$getOutMachineCount$382bb5439d011100;
extern _jc_method _jc_soot_baf_internal_BInstanceCastInst$method_info$setCastType$d5c81c672c992d0a;

// Virtual methods structure
struct _jc_soot_baf_internal_BInstanceCastInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getCastType$ae2cd82a88b9d4af)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *) _JC_JCNI_ATTR;
	void	(*setCastType$d5c81c672c992d0a)(_jc_env *, struct _jc_soot_baf_internal_BInstanceCastInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BInstanceCastInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_BInstanceCastInst$vmethods	soot_baf_internal_BInstanceCastInst;
};

// Vtype
struct _jc_soot_baf_internal_BInstanceCastInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BInstanceCastInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BInstanceCastInst$sub_refs {
	struct _jc_soot_Type$object	*castType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BInstanceCastInst$refs {
    _jc_soot_baf_internal_BInstanceCastInst$sub_refs	soot_baf_internal_BInstanceCastInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BInstanceCastInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BInstanceCastInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_BInstanceCastInst$sub_nonrefs	soot_baf_internal_BInstanceCastInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BInstanceCastInst$object {
	_jc_soot_baf_internal_BInstanceCastInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BInstanceCastInst$vtype	*vtype;
	_jc_soot_baf_internal_BInstanceCastInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BInstanceCastInst$vtype _jc_soot_baf_internal_BInstanceCastInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BInstanceCastInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BInstanceCastInst$class_object;

#endif	/* _JC_soot_baf_internal_BInstanceCastInst_H_ */
